@@ -33,6 +33,7 @@ from digi import (
     util,
     view,
     filter,
+    mount,
 )
 from digi.main import run
 from digi.reconcile import rc
@@ -40,6 +41,5 @@ auri = (rc.g, rc.v, rc.r, rc.n, rc.ns)
 
 __all__ = [
     "on", "util", "view", "filter",
-    "run", "logger", "auri"
-
+    "run", "logger", "auri", "mount"
 ]
